@@ -14,13 +14,13 @@ from django.conf import settings as django_settings
 from django.urls import reverse
 
 from polaris import settings
-from polaris.utils import Logger
+from polaris.utils import getLogger
 from polaris.middleware import import_path
 from polaris.models import Asset, Transaction
 from polaris.utils import render_error_response, verify_valid_asset_operation
 
 
-logger = Logger(__name__)
+logger = getLogger(__name__)
 
 
 def check_authentication(content_type: str = "text/html") -> Callable:
@@ -235,20 +235,12 @@ def check_sep24_config():
 def check_middleware():
     """
     Ensures the Django app running Polaris has the correct middleware
-    configuration. Polaris requires SessionMiddleware and
-    PolarisSameSiteMiddleware to be installed.
+    configuration. Polaris requires SessionMiddleware to be installed.
     """
     err_msg = "{} is not installed in settings.MIDDLEWARE"
     session_middleware_path = "django.contrib.sessions.middleware.SessionMiddleware"
-    if import_path not in django_settings.MIDDLEWARE:
-        raise ValueError(err_msg.format(import_path))
-    elif session_middleware_path not in django_settings.MIDDLEWARE:
+    if session_middleware_path not in django_settings.MIDDLEWARE:
         raise ValueError(err_msg.format(session_middleware_path))
-    elif django_settings.MIDDLEWARE.index(
-        import_path
-    ) > django_settings.MIDDLEWARE.index(session_middleware_path):
-        err_msg = f"{import_path} must be listed before {session_middleware_path}"
-        raise ValueError(err_msg)
 
 
 def check_protocol():
@@ -261,15 +253,21 @@ def check_protocol():
 
 
 def interactive_url(
-    request: Request, transaction_id: str, account: str, asset_code: str, op_type: str
+    request: Request,
+    transaction_id: str,
+    account: str,
+    asset_code: str,
+    op_type: str,
+    amount: Optional[Decimal],
 ) -> Optional[str]:
-    qparams = urlencode(
-        {
-            "asset_code": asset_code,
-            "transaction_id": transaction_id,
-            "token": generate_interactive_jwt(request, transaction_id, account),
-        }
-    )
+    params = {
+        "asset_code": asset_code,
+        "transaction_id": transaction_id,
+        "token": generate_interactive_jwt(request, transaction_id, account),
+    }
+    if amount:
+        params["amount"] = amount
+    qparams = urlencode(params)
     if op_type == settings.OPERATION_WITHDRAWAL:
         url_params = f"{reverse('get_interactive_withdraw')}?{qparams}"
     else:
