@@ -3,7 +3,9 @@ This module implements the logic for the `/transactions/withdraw` endpoint.
 This lets a user withdraw some asset from their Stellar account into a
 non-Stellar-based account.
 """
+from decimal import Decimal, DecimalException
 from urllib.parse import urlencode
+from polaris.utils import getLogger
 
 from django.urls import reverse
 from django.views.decorators.clickjacking import xframe_options_exempt
@@ -18,7 +20,6 @@ from polaris import settings
 from polaris.templates import Template
 from polaris.utils import (
     render_error_response,
-    Logger,
     extract_sep9_fields,
     create_transaction_id,
     memo_hex_to_base64,
@@ -42,7 +43,7 @@ from polaris.integrations import (
     calculate_fee,
 )
 
-logger = Logger(__name__)
+logger = getLogger(__name__)
 
 
 @xframe_options_exempt
@@ -81,9 +82,6 @@ def post_interactive_withdraw(request: Request) -> Response:
     amount = args_or_error["amount"]
 
     form = rwi.form_for_transaction(transaction, post_data=request.POST)
-    content = rwi.content_for_template(
-        Template.WITHDRAW, form=form, transaction=transaction
-    )
     if not form:
         logger.error(
             "Initial form_for_transaction() call returned None " f"for {transaction.id}"
@@ -154,6 +152,12 @@ def post_interactive_withdraw(request: Request) -> Response:
             return redirect(f"{url}?{args}")
 
     else:
+        content = (
+            rwi.content_for_template(
+                Template.WITHDRAW, form=form, transaction=transaction
+            )
+            or {}
+        )
         scripts = registered_scripts_func({"form": form, **content})
 
         url_args = {"transaction_id": transaction.id, "asset_code": asset.code}
@@ -166,6 +170,7 @@ def post_interactive_withdraw(request: Request) -> Response:
         post_url = f"{reverse('post_interactive_deposit')}?{urlencode(url_args)}"
         get_url = f"{reverse('get_interactive_deposit')}?{urlencode(url_args)}"
         content.update(
+            form=form,
             post_url=post_url,
             get_url=get_url,
             scripts=scripts,
@@ -314,6 +319,13 @@ def withdraw(account: str, request: Request) -> Response:
         # require new or adjusted integration points.
         return render_error_response(_("`memo` parameter is not supported"))
 
+    amount = None
+    if request.POST.get("amount"):
+        try:
+            amount = Decimal(request.POST.get("amount"))
+        except DecimalException as e:
+            return render_error_response(_("Invalid 'amount'"))
+
     # Verify that the asset code exists in our database, with withdraw enabled.
     asset = Asset.objects.filter(code=asset_code).first()
     if not (asset and asset.withdrawal_enabled and asset.sep24_enabled):
@@ -343,7 +355,12 @@ def withdraw(account: str, request: Request) -> Response:
     logger.info(f"Created withdrawal transaction {transaction_id}")
 
     url = interactive_url(
-        request, str(transaction_id), account, asset_code, settings.OPERATION_WITHDRAWAL
+        request,
+        str(transaction_id),
+        account,
+        asset_code,
+        settings.OPERATION_WITHDRAWAL,
+        amount,
     )
     return Response(
         {"type": "interactive_customer_info_needed", "url": url, "id": transaction_id}
